@@ -74,7 +74,8 @@ _DASK_INDEX: Final = "dask.dataframe.dask_expr._collection.Index"
 _DASK_DATAFRAME_LEGACY: Final = "dask.dataframe.core.DataFrame"
 _DASK_SERIES_LEGACY: Final = "dask.dataframe.core.Series"
 _DASK_INDEX_LEGACY: Final = "dask.dataframe.core.Index"
-_DUCKDB_RELATION: Final = "duckdb.duckdb.DuckDBPyRelation"
+_DUCKDB_RELATION: Final = "_duckdb.DuckDBPyRelation"
+_DUCKDB_RELATION_LEGACY: Final = "duckdb.duckdb.DuckDBPyRelation"
 _MODIN_DF_TYPE_STR: Final = "modin.pandas.dataframe.DataFrame"
 _MODIN_SERIES_TYPE_STR: Final = "modin.pandas.series.Series"
 _PANDAS_STYLER_TYPE_STR: Final = "pandas.io.formats.style.Styler"
@@ -452,7 +453,7 @@ def is_duckdb_relation(obj: object) -> bool:
     https://duckdb.org/docs/api/python/relational_api
     """
 
-    return is_type(obj, _DUCKDB_RELATION)
+    return is_type(obj, _DUCKDB_RELATION) or is_type(obj, _DUCKDB_RELATION_LEGACY)
 
 
 def _is_list_of_scalars(data: Iterable[Any]) -> bool:
@@ -1076,7 +1077,7 @@ def is_colum_type_arrow_incompatible(column: Series[Any] | Index) -> bool:
                 return True
 
             # Get the first value to check if it is a supported list-like type.
-            first_value = column.iloc[0]
+            first_value = cast("DataFrameGenericAlias[Any]", column).iloc[0]
 
             if (  # noqa: SIM103
                 not is_list_like(first_value)
