@@ -323,7 +323,7 @@ class LayoutsMixin:
             # in the future. This might require including more container
             # parameters in the ID calculation.
             block_proto.id = compute_and_register_element_id(
-                "container", user_key=key, dg=None
+                "container", user_key=key, dg=None, key_as_main_identity=False
             )
 
         return self.dg._block(block_proto)
@@ -559,6 +559,7 @@ class LayoutsMixin:
         tabs: Sequence[str],
         *,
         width: WidthWithoutContent = "stretch",
+        default: str | None = None,
     ) -> Sequence[DeltaGenerator]:
         r"""Insert containers separated into tabs.
 
@@ -568,7 +569,7 @@ class LayoutsMixin:
 
         To add elements to the returned containers, you can use the ``with`` notation
         (preferred) or just call methods directly on the returned object. See
-        examples below.
+        the examples below.
 
         .. note::
             All content within every tab is computed and sent to the frontend,
@@ -608,6 +609,12 @@ class LayoutsMixin:
               the parent container, the width of the container matches the width
               of the parent container.
 
+        default : str or None
+            The default tab to select. If this is ``None`` (default), the first
+            tab is selected. If this is a string, it must be one of the tab
+            labels. If two tabs have the same label as ``default``, the first
+            one is selected.
+
         Returns
         -------
         list of containers
@@ -615,7 +622,9 @@ class LayoutsMixin:
 
         Examples
         --------
-        You can use the ``with`` notation to insert any element into a tab:
+        *Example 1: Use context management*
+
+        You can use ``with`` notation to insert any element into a tab:
 
         >>> import streamlit as st
         >>>
@@ -635,7 +644,9 @@ class LayoutsMixin:
             https://doc-tabs1.streamlit.app/
             height: 620px
 
-        Or you can just call methods directly on the returned objects:
+        *Example 2: Call methods directly*
+
+        You can call methods directly on the returned objects:
 
         >>> import streamlit as st
         >>> from numpy.random import default_rng as rng
@@ -654,12 +665,42 @@ class LayoutsMixin:
             https://doc-tabs2.streamlit.app/
             height: 700px
 
+        *Example 3: Set the default tab and style the tab labels*
+
+        Use the ``default`` parameter to set the default tab. You can also use
+        Markdown in the tab labels.
+
+        >>> import streamlit as st
+        >>>
+        >>> tab1, tab2, tab3 = st.tabs(
+        ...     [":cat: Cat", ":dog: Dog", ":rainbow[Owl]"], default=":rainbow[Owl]"
+        ... )
+        >>>
+        >>> with tab1:
+        >>>     st.header("A cat")
+        >>>     st.image("https://static.streamlit.io/examples/cat.jpg", width=200)
+        >>> with tab2:
+        >>>     st.header("A dog")
+        >>>     st.image("https://static.streamlit.io/examples/dog.jpg", width=200)
+        >>> with tab3:
+        >>>     st.header("An owl")
+        >>>     st.image("https://static.streamlit.io/examples/owl.jpg", width=200)
+
+        .. output ::
+            https://doc-tabs3.streamlit.app/
+            height: 620px
+
         """
         if not tabs:
             raise StreamlitAPIException(
                 "The input argument to st.tabs must contain at least one tab label."
             )
 
+        if default and default not in tabs:
+            raise StreamlitAPIException(
+                f"The default tab '{default}' is not in the list of tabs."
+            )
+
         if any(not isinstance(tab, str) for tab in tabs):
             raise StreamlitAPIException(
                 "The tabs input list to st.tabs is only allowed to contain strings."
@@ -675,8 +716,14 @@ class LayoutsMixin:
         block_proto.tab_container.SetInParent()
         validate_width(width)
         block_proto.width_config.CopyFrom(get_width_config(width))
+
+        default_index = tabs.index(default) if default else 0
+
+        block_proto.tab_container.default_tab_index = default_index
+
         tab_container = self.dg._block(block_proto)
-        return tuple(tab_container._block(tab_proto(tab_label)) for tab_label in tabs)
+
+        return tuple(tab_container._block(tab_proto(tab)) for tab in tabs)
 
     @gather_metrics("expander")
     def expander(
@@ -899,6 +946,12 @@ class LayoutsMixin:
             button. The popover container may be wider than its button to fit
             the container's content.
 
+            .. deprecated::
+                ``use_container_width`` is deprecated and will be removed in a
+                future release. For ``use_container_width=True``, use
+                ``width="stretch"``. For ``use_container_width=False``, use
+                ``width="content"``.
+
         width : int, "stretch", or "content"
             The width of the button. This can be one of the following:
 
@@ -916,12 +969,6 @@ class LayoutsMixin:
             button. The popover container may be wider than its button to fit
             the container's contents.
 
-        .. deprecated::
-            ``use_container_width`` is deprecated and will be removed in a
-            future release. For ``use_container_width=True``, use
-            ``width="stretch"``. For ``use_container_width=False``, use
-            ``width="content"``.
-
         Examples
         --------
         You can use the ``with`` notation to insert any element into a popover:
