@@ -20,20 +20,15 @@ import json
 import re
 from contextlib import nullcontext
 from dataclasses import dataclass
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Final,
-    Literal,
-    TypedDict,
-    Union,
-    cast,
-    overload,
-)
+from typing import TYPE_CHECKING, Any, Final, Literal, TypedDict, Union, cast, overload
 
 from typing_extensions import Required, TypeAlias
 
 from streamlit import dataframe_util, type_util
+from streamlit.deprecation_util import (
+    make_deprecated_name_warning,
+    show_deprecation_warning,
+)
 from streamlit.elements.lib import dicttools
 from streamlit.elements.lib.built_in_chart_utils import (
     AddRowsMetadata,
@@ -43,6 +38,13 @@ from streamlit.elements.lib.built_in_chart_utils import (
     maybe_raise_stack_warning,
 )
 from streamlit.elements.lib.form_utils import current_form_id
+from streamlit.elements.lib.layout_utils import (
+    Height,
+    LayoutConfig,
+    Width,
+    validate_height,
+    validate_width,
+)
 from streamlit.elements.lib.policies import check_widget_policies
 from streamlit.elements.lib.utils import Key, compute_and_register_element_id, to_key
 from streamlit.errors import StreamlitAPIException
@@ -596,9 +598,9 @@ class VegaChartsMixin:
         x_label: str | None = None,
         y_label: str | None = None,
         color: str | Color | list[Color] | None = None,
-        width: int | None = None,
-        height: int | None = None,
-        use_container_width: bool = True,
+        width: Width = "stretch",
+        height: Height = "content",
+        use_container_width: bool | None = None,
     ) -> DeltaGenerator:
         """Display a line chart.
 
@@ -607,9 +609,6 @@ class VegaChartsMixin:
         the chart's Altair spec. As a result this is easier to use for many
         "just plot this" scenarios, while being less customizable.
 
-        If ``st.line_chart`` does not guess the data specification
-        correctly, try specifying your desired chart using ``st.altair_chart``.
-
         Parameters
         ----------
         data : Anything supported by st.dataframe
@@ -680,20 +679,30 @@ class VegaChartsMixin:
             You can set the default colors in the ``theme.chartCategoryColors``
             configuration option.
 
-        width : int or None
-            Desired width of the chart expressed in pixels. If ``width`` is
-            ``None`` (default), Streamlit sets the width of the chart to fit
-            its contents according to the plotting library, up to the width of
-            the parent container. If ``width`` is greater than the width of the
-            parent container, Streamlit sets the chart width to match the width
-            of the parent container.
+        width : "stretch", "content", or int
+            The width of the chart element. This can be one of the following:
 
-            To use ``width``, you must set ``use_container_width=False``.
+            - ``"stretch"`` (default): The width of the element matches the
+              width of the parent container.
+            - ``"content"``: The width of the element matches the width of its
+              content, but doesn't exceed the width of the parent container.
+            - An integer specifying the width in pixels: The element has a
+              fixed width. If the specified width is greater than the width of
+              the parent container, the width of the element matches the width
+              of the parent container.
 
-        height : int or None
-            Desired height of the chart expressed in pixels. If ``height`` is
-            ``None`` (default), Streamlit sets the height of the chart to fit
-            its contents according to the plotting library.
+        height : "content", "stretch", or int
+            The height of the chart element. This can be one of the following:
+
+            - ``"content"`` (default): The height of the element matches the
+              height of its content.
+            - ``"stretch"``: The height of the element matches the height of
+              its content or the height of the parent container, whichever is
+              larger. If the element is not in a parent container, the height
+              of the element matches the height of its content.
+            - An integer specifying the height in pixels: The element has a
+              fixed height. If the content is larger than the specified
+              height, scrolling is enabled.
 
         use_container_width : bool
             Whether to override ``width`` with the width of the parent
@@ -702,6 +711,11 @@ class VegaChartsMixin:
             parent container. If ``use_container_width`` is ``False``,
             Streamlit sets the chart's width according to ``width``.
 
+            .. deprecated::
+                The ``use_container_width`` parameter is deprecated and will
+                be removed in a future version. Use the ``width`` parameter
+                with ``width="stretch"`` instead.
+
         Examples
         --------
         **Example 1: Basic line chart from a dataframe**
@@ -777,6 +791,24 @@ class VegaChartsMixin:
            height: 440px
 
         """
+        if use_container_width is not None:
+            show_deprecation_warning(
+                make_deprecated_name_warning(
+                    "use_container_width",
+                    "width",
+                    "2025-12-31",
+                    "For `use_container_width=True`, use `width='stretch'`. "
+                    "For `use_container_width=False`, use `width='content'`.",
+                    include_st_prefix=False,
+                ),
+                show_in_browser=False,
+            )
+            if use_container_width:
+                width = "stretch"
+            elif not isinstance(width, int):
+                # This preserves the existing behavior of setting use_container_width
+                # to False combined with an integer width.
+                width = "content"
 
         chart, add_rows_metadata = generate_chart(
             chart_type=ChartType.LINE,
@@ -789,15 +821,19 @@ class VegaChartsMixin:
             size_from_user=None,
             width=width,
             height=height,
-            use_container_width=use_container_width,
+            use_container_width=(width == "stretch"),
         )
+
+        validate_width(width, allow_content=True)
+        validate_height(height, allow_content=True)
         return cast(
             "DeltaGenerator",
             self._altair_chart(
                 chart,
-                use_container_width=use_container_width,
                 theme="streamlit",
                 add_rows_metadata=add_rows_metadata,
+                width=width,
+                height=height,
             ),
         )
 
@@ -823,9 +859,6 @@ class VegaChartsMixin:
         the chart's Altair spec. As a result this is easier to use for many
         "just plot this" scenarios, while being less customizable.
 
-        If ``st.area_chart`` does not guess the data specification
-        correctly, try specifying your desired chart using ``st.altair_chart``.
-
         Parameters
         ----------
         data : Anything supported by st.dataframe
@@ -1082,6 +1115,7 @@ class VegaChartsMixin:
         y_label: str | None = None,
         color: str | Color | list[Color] | None = None,
         horizontal: bool = False,
+        sort: bool | str = True,
         stack: bool | ChartStackType | None = None,
         width: int | None = None,
         height: int | None = None,
@@ -1094,9 +1128,6 @@ class VegaChartsMixin:
         the chart's Altair spec. As a result this is easier to use for many
         "just plot this" scenarios, while being less customizable.
 
-        If ``st.bar_chart`` does not guess the data specification
-        correctly, try specifying your desired chart using ``st.altair_chart``.
-
         Parameters
         ----------
         data : Anything supported by st.dataframe
@@ -1173,6 +1204,19 @@ class VegaChartsMixin:
             Streamlit swaps the x-axis and y-axis and the bars display
             horizontally.
 
+        sort : bool or str
+            How to sort the bars. This can be one of the following:
+
+            - ``True`` (default): The bars are sorted automatically along the
+              independent/categorical axis with Altair's default sorting. This
+              also correctly sorts ordered categorical columns
+              (``pd.Categorical``).
+            - ``False``: The bars are shown in data order without sorting.
+            - The name of a column (e.g. ``"col1"``): The bars are sorted by
+              that column in ascending order.
+            - The name of a column with a minus-sign prefix (e.g. ``"-col1"``):
+              The bars are sorted by that column in descending order.
+
         stack : bool, "normalize", "center", "layered", or None
             Whether to stack the bars. If this is ``None`` (default),
             Streamlit uses Vega's default. Other values can be as follows:
@@ -1357,6 +1401,7 @@ class VegaChartsMixin:
             use_container_width=use_container_width,
             stack=stack,
             horizontal=horizontal,
+            sort_from_user=sort,
         )
         return cast(
             "DeltaGenerator",
@@ -1390,9 +1435,6 @@ class VegaChartsMixin:
         the chart's Altair spec. As a result this is easier to use for many
         "just plot this" scenarios, while being less customizable.
 
-        If ``st.scatter_chart`` does not guess the data specification correctly,
-        try specifying your desired chart using ``st.altair_chart``.
-
         Parameters
         ----------
         data : Anything supported by st.dataframe
@@ -1956,6 +1998,8 @@ class VegaChartsMixin:
         on_select: Literal["rerun", "ignore"] | WidgetCallback = "ignore",
         selection_mode: str | Iterable[str] | None = None,
         add_rows_metadata: AddRowsMetadata | None = None,
+        width: Width | None = None,
+        height: Height | None = None,
     ) -> DeltaGenerator | VegaLiteState:
         """Internal method to enqueue a vega-lite chart element based on an Altair chart.
 
@@ -1980,6 +2024,8 @@ class VegaChartsMixin:
             on_select=on_select,
             selection_mode=selection_mode,
             add_rows_metadata=add_rows_metadata,
+            width=width,
+            height=height,
         )
 
     def _vega_lite_chart(
@@ -1992,6 +2038,8 @@ class VegaChartsMixin:
         on_select: Literal["rerun", "ignore"] | WidgetCallback = "ignore",
         selection_mode: str | Iterable[str] | None = None,
         add_rows_metadata: AddRowsMetadata | None = None,
+        width: Width | None = None,
+        height: Height | None = None,
         **kwargs: Any,
     ) -> DeltaGenerator | VegaLiteState:
         """Internal method to enqueue a vega-lite chart element based on a vega-lite spec.
@@ -2038,13 +2086,13 @@ class VegaChartsMixin:
             spec = {}
 
         # Set the default value for `use_container_width`.
-        if use_container_width is None:
+        if use_container_width is None and width is None:
             # Some multi-view charts (facet, horizontal concatenation, and repeat;
             # see https://altair-viz.github.io/user_guide/compound_charts.html)
             # don't work well with `use_container_width=True`, so we disable it for
             # those charts (see https://github.com/streamlit/streamlit/issues/9091).
             # All other charts (including vertical concatenation) default to
-            # `use_container_width=True`.
+            # `use_container_width=True` unless width is provided.
             is_facet_chart = "facet" in spec or (
                 "encoding" in spec
                 and (any(x in spec["encoding"] for x in ["row", "column", "facet"]))
@@ -2055,12 +2103,18 @@ class VegaChartsMixin:
 
         vega_lite_proto = ArrowVegaLiteChartProto()
 
-        spec = _prepare_vega_lite_spec(spec, use_container_width, **kwargs)
+        use_container_width_for_spec = (
+            use_container_width
+            if use_container_width is not None
+            else width == "stretch"
+        )
+        spec = _prepare_vega_lite_spec(spec, use_container_width_for_spec, **kwargs)
         _marshall_chart_data(vega_lite_proto, spec, data)
 
         # Prevent the spec from changing across reruns:
         vega_lite_proto.spec = _stabilize_vega_json_spec(json.dumps(spec))
-        vega_lite_proto.use_container_width = use_container_width
+        if use_container_width is not None:
+            vega_lite_proto.use_container_width = use_container_width
         vega_lite_proto.theme = theme or ""
 
         if is_selection_activated:
@@ -2079,6 +2133,7 @@ class VegaChartsMixin:
             vega_lite_proto.id = compute_and_register_element_id(
                 "arrow_vega_lite_chart",
                 user_key=key,
+                key_as_main_identity=False,
                 dg=self.dg,
                 vega_lite_spec=vega_lite_proto.spec,
                 # The data is either in vega_lite_proto.data.data
@@ -2109,6 +2164,17 @@ class VegaChartsMixin:
                 add_rows_metadata=add_rows_metadata,
             )
             return widget_state.value
+
+        # Handle layout config for width/height parameters
+        if width is not None or height is not None:
+            layout_config = LayoutConfig(width=width, height=height)
+            return self.dg._enqueue(
+                "arrow_vega_lite_chart",
+                vega_lite_proto,
+                add_rows_metadata=add_rows_metadata,
+                layout_config=layout_config,
+            )
+
         # If its not used with selections activated, just return
         # the delta generator related to this element.
         return self.dg._enqueue(
