@@ -188,6 +188,12 @@ class ButtonMixin:
             In both cases, if the contents of the button are wider than the
             parent container, the contents will line wrap.
 
+            .. deprecated::
+                ``use_container_width`` is deprecated and will be removed in a
+                future release. For ``use_container_width=True``, use
+                ``width="stretch"``. For ``use_container_width=False``, use
+                ``width="content"``.
+
         width : "content", "stretch", or int
             The width of the button. This can be one of the following:
 
@@ -201,12 +207,6 @@ class ButtonMixin:
               the parent container, the width of the button matches the width
               of the parent container.
 
-        .. deprecated::
-            ``use_container_width`` is deprecated and will be removed in a
-            future release. For ``use_container_width=True``, use
-            ``width="stretch"``. For ``use_container_width=False``, use
-            ``width="content"``.
-
         Returns
         -------
         bool
@@ -432,6 +432,12 @@ class ButtonMixin:
             In both cases, if the contents of the button are wider than the
             parent container, the contents will line wrap.
 
+            .. deprecated::
+                ``use_container_width`` is deprecated and will be removed in a
+                future release. For ``use_container_width=True``, use
+                ``width="stretch"``. For ``use_container_width=False``, use
+                ``width="content"``.
+
         width : "content", "stretch", or int
             The width of the download button. This can be one of the following:
 
@@ -445,12 +451,6 @@ class ButtonMixin:
               the parent container, the width of the button matches the width
               of the parent container.
 
-        .. deprecated::
-            ``use_container_width`` is deprecated and will be removed in a
-            future release. For ``use_container_width=True``, use
-            ``width="stretch"``. For ``use_container_width=False``, use
-            ``width="content"``.
-
         Returns
         -------
         bool
@@ -680,6 +680,12 @@ class ButtonMixin:
             In both cases, if the contents of the button are wider than the
             parent container, the contents will line wrap.
 
+            .. deprecated::
+                ``use_container_width`` is deprecated and will be removed in a
+                future release. For ``use_container_width=True``, use
+                ``width="stretch"``. For ``use_container_width=False``, use
+                ``width="content"``.
+
         width : "content", "stretch", or int
             The width of the link button. This can be one of the following:
 
@@ -693,12 +699,6 @@ class ButtonMixin:
               the parent container, the width of the button matches the width
               of the parent container.
 
-        .. deprecated::
-            ``use_container_width`` is deprecated and will be removed in a
-            future release. For ``use_container_width=True``, use
-            ``width="stretch"``. For ``use_container_width=False``, use
-            ``width="content"``.
-
         Example
         -------
         >>> import streamlit as st
@@ -812,6 +812,12 @@ class ButtonMixin:
             The default is ``True`` for page links in the sidebar and ``False``
             for those in the main app.
 
+            .. deprecated::
+                ``use_container_width`` is deprecated and will be removed in a
+                future release. For ``use_container_width=True``, use
+                ``width="stretch"``. For ``use_container_width=False``, use
+                ``width="content"``.
+
         width : "content", "stretch", or int
             The width of the page-link button. This can be one of the following:
 
@@ -825,12 +831,6 @@ class ButtonMixin:
               the parent container, the width of the button matches the width
               of the parent container.
 
-        .. deprecated::
-            ``use_container_width`` is deprecated and will be removed in a
-            future release. For ``use_container_width=True``, use
-            ``width="stretch"``. For ``use_container_width=False``, use
-            ``width="content"``.
-
         Example
         -------
         Consider the following example given this file structure:
@@ -914,6 +914,7 @@ class ButtonMixin:
         element_id = compute_and_register_element_id(
             "download_button",
             user_key=key,
+            key_as_main_identity=True,
             dg=self.dg,
             label=label,
             icon=icon,
@@ -1119,8 +1120,9 @@ class ButtonMixin:
         # Only the form submitter button needs a form ID at the moment.
         form_id = current_form_id(self.dg) if is_form_submitter else ""
         element_id = compute_and_register_element_id(
-            "button",
+            "form_submit_button" if is_form_submitter else "button",
             user_key=key,
+            key_as_main_identity=True,
             dg=self.dg,
             label=label,
             icon=icon,
