@@ -37,7 +37,6 @@ from typing import (
 
 from streamlit import dataframe_util, type_util
 from streamlit.errors import StreamlitAPIException
-from streamlit.logger import get_logger
 from streamlit.runtime.metrics_util import gather_metrics
 from streamlit.string_util import (
     is_mem_address_str,
@@ -56,7 +55,6 @@ HELP_TYPES: Final[tuple[type[Any], ...]] = (
     types.ModuleType,
 )
 
-_LOGGER: Final = get_logger(__name__)
 
 _TEXT_CURSOR: Final = " ▏"
 
@@ -86,7 +84,8 @@ class WriteMixin:
             The generator or iterable to stream.
 
             If you pass an async generator, Streamlit will internally convert
-            it to a sync generator.
+            it to a sync generator. If the generator depends on a cached object
+            with async references, this can raise an error.
 
             .. note::
                 To use additional LLM libraries, you can create a wrapper to
@@ -208,7 +207,7 @@ class WriteMixin:
             if type_util.is_type(chunk, "langchain_core.messages.ai.AIMessageChunk"):
                 # Try to convert LangChain message chunk to a string:
                 try:
-                    chunk = chunk.content or ""  # noqa: PLW2901
+                    chunk = chunk.content or ""  # noqa: PLW2901 # type: ignore[possibly-unbound-attribute]
                 except AttributeError as err:
                     raise StreamlitAPIException(
                         "Failed to parse the LangChain AIMessageChunk. "
@@ -253,7 +252,7 @@ class WriteMixin:
         return written_content
 
     @gather_metrics("write")
-    def write(self, *args: Any, unsafe_allow_html: bool = False, **kwargs: Any) -> None:
+    def write(self, *args: Any, unsafe_allow_html: bool = False) -> None:
         """Displays arguments in the app.
 
         This is the Swiss Army knife of Streamlit commands: it does different
@@ -322,13 +321,6 @@ class WriteMixin:
                 If you only want to insert HTML or CSS without Markdown text,
                 we recommend using ``st.html`` instead.
 
-        **kwargs : any
-            Keyword arguments. Not used.
-
-        .. deprecated::
-            ``**kwargs`` is deprecated and will be removed in a later version.
-            Use other, more specific Streamlit commands to pass additional
-            keyword arguments.
 
         Returns
         -------
@@ -380,32 +372,25 @@ class WriteMixin:
 
         Oh, one more thing: ``st.write`` accepts chart objects too! For example:
 
-        >>> import streamlit as st
-        >>> import pandas as pd
-        >>> import numpy as np
         >>> import altair as alt
+        >>> import pandas as pd
+        >>> import streamlit as st
+        >>> from numpy.random import default_rng as rng
         >>>
-        >>> df = pd.DataFrame(np.random.randn(200, 3), columns=["a", "b", "c"])
-        >>> c = (
+        >>> df = pd.DataFrame(rng(0).standard_normal((200, 3)), columns=["a", "b", "c"])
+        >>> chart = (
         ...     alt.Chart(df)
         ...     .mark_circle()
         ...     .encode(x="a", y="b", size="c", color="c", tooltip=["a", "b", "c"])
         ... )
         >>>
-        >>> st.write(c)
+        >>> st.write(chart)
 
         ..  output::
             https://doc-vega-lite-chart.streamlit.app/
             height: 300px
 
         """
-        if kwargs:
-            _LOGGER.warning(
-                'Invalid arguments were passed to "st.write" function. Support for '
-                "passing such unknown keywords arguments will be dropped in future. "
-                "Invalid arguments were: %s",
-                kwargs,
-            )
 
         if len(args) == 1 and isinstance(args[0], str):
             # Optimization: If there is only one arg, and it's a string,
