@@ -85,7 +85,7 @@ class WebsocketSessionManager(SessionManager):
             and self._session_storage.get(existing_session_id)
         )
 
-        if session_info:
+        if isinstance(session_info, SessionInfo):
             existing_session = session_info.session
             existing_session.register_file_watchers()
 
@@ -137,6 +137,10 @@ class WebsocketSessionManager(SessionManager):
             )
             del self._active_session_info_by_id[session_id]
 
+        if not self._active_session_info_by_id:
+            # Avoid stale cached scripts when all file watchers and sessions are disconnected
+            self._script_cache.clear()
+
     def get_active_session_info(self, session_id: str) -> ActiveSessionInfo | None:
         return self._active_session_info_by_id.get(session_id)
 
@@ -151,6 +155,10 @@ class WebsocketSessionManager(SessionManager):
             active_session_info = self._active_session_info_by_id[session_id]
             del self._active_session_info_by_id[session_id]
             active_session_info.session.shutdown()
+
+            if not self._active_session_info_by_id:
+                # Avoid stale cached scripts when all file watchers and sessions are disconnected
+                self._script_cache.clear()
             return
 
         session_info = self._session_storage.get(session_id)
