@@ -13,14 +13,18 @@
 # limitations under the License.
 
 from streamlit.web.server.component_request_handler import ComponentRequestHandler
-from streamlit.web.server.routes import allow_cross_origin_requests
+from streamlit.web.server.routes import (
+    allow_all_cross_origin_requests,
+    is_allowed_origin,
+)
 from streamlit.web.server.server import Server, server_address_is_unix_socket
 from streamlit.web.server.stats_request_handler import StatsRequestHandler
 
 __all__ = [
     "ComponentRequestHandler",
-    "allow_cross_origin_requests",
     "Server",
-    "server_address_is_unix_socket",
     "StatsRequestHandler",
+    "allow_all_cross_origin_requests",
+    "is_allowed_origin",
+    "server_address_is_unix_socket",
 ]
